@@ -9,18 +9,18 @@ from fastapi import APIRouter, WebSocket, Response, Depends, status
 from fastapi.responses import FileResponse
 from starlette.requests import Request  # type: ignore
 
-from fps_auth.routes import cookie_authentication, current_user  # type: ignore
-from fps_auth.models import User, user_db  # type: ignore
+from fps_auth.backends import cookie_authentication, current_user  # type: ignore
+from fps_auth.models import User  # type: ignore
+from fps_auth.db import get_user_db  # type: ignore
 from fps_auth.config import get_auth_config  # type: ignore
 
-from .kernel_server.server import KernelServer  # type: ignore
+from .kernel_server.server import KernelServer, kernels  # type: ignore
 from .models import Session
 
 router = APIRouter()
 
 kernelspecs: dict = {}
 sessions: dict = {}
-kernels: dict = {}
 prefix_dir: pathlib.Path = pathlib.Path(sys.prefix)
 
 
@@ -164,9 +164,30 @@ async def restart_kernel(
         return result
 
 
+@router.get("/api/kernels/{kernel_id}")
+async def get_kernel(
+    kernel_id,
+    user: User = Depends(current_user()),
+):
+    if kernel_id in kernels:
+        kernel = kernels[kernel_id]
+        result = {
+            "id": kernel_id,
+            "name": kernel["name"],
+            "connections": kernel["server"].connections,
+            "last_activity": kernel["server"].last_activity["date"],
+            "execution_state": kernel["server"].last_activity["execution_state"],
+        }
+        return result
+
+
 @router.websocket("/api/kernels/{kernel_id}/channels")
 async def kernel_channels(
-    websocket: WebSocket, kernel_id, session_id, auth_config=Depends(get_auth_config)
+    websocket: WebSocket,
+    kernel_id,
+    session_id,
+    auth_config=Depends(get_auth_config),
+    user_db=Depends(get_user_db),
 ):
     accept_websocket = False
     if auth_config.mode == "noauth":
